#
# venexma.pl - Plugin para Webon 2.0.
#
# Copyright (C) 2004, 2005 Angel Ortega <angel@venexma.es>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

package Webon::Plugins::Venexma;

use Text::Iconv;

# crea un objeto Text::Iconv para convertir de utf-8 a iso-8859-1
my $utf_conv = Text::Iconv->new('utf-8', 'iso-8859-1');

# obtiene el objeto Webon
$w = $Webon::plugin;

push(@{$w->{'flow'}->{'pre'}},  "Webon::Plugins::Venexma::mkdir_docs");
push(@{$w->{'flow'}->{'main'}}, "Webon::Plugins::Venexma::build_docs");
push(@{$w->{'flow'}->{'main'}}, "Webon::Plugins::Venexma::link_pages");
push(@{$w->{'flow'}->{'main'}}, "Webon::Plugins::Venexma::brands_page");

###############################################################

sub mkdir_docs
# crea el directorio docs
{
	my ($w) = @_;

	mkdir "./docs";
}


sub build_docs
# construye los documentos para imprimir
{
	my ($w, $lang) = @_;

	print "\t(Venexma) docs...\n" if $w->{'verbose'};

	# recorre el catálogo generando los índices
	foreach my $c (@{$w->{'catalog'}})
	{
		# si no tiene artículos, no lo genera
		next if scalar($w->get_articles($c)) == 0;

		my $vars = $w->default_tt_vars($lang, $c);

		$w->process_template('doc_index', $vars,
			"./docs/${lang}-${c}.html", $utf_conv);
	}
}


sub link_pages
# enlaza las páginas genéricas al directorio de documentos
{
	my ($w, $lang) = @_;

	print "\t(Venexma) pages...\n" if $w->{'verbose'};

#	foreach my $p (@{$w->{'pages'}})
#	{
#		my ($org) = $w->{'output'} . "/$lang-$p.html";
#		my ($dest) = "./docs/$lang-$p.html";
#
#		$w->hardlink_if_diff($org, $dest);
#	}

	# recorre las páginas
	foreach my $p (@{$w->{'pages'}})
	{
		my $o = $p;

		# FIXME: demasiado dependiente de venexma.es
		$o =~ s/_COLOR$//;

		my $title = $w->{'L'}->{$p} || $w->{'L'}->{$o};

		my $vars = $w->default_tt_vars($lang, $p);
		$vars->{'title'} = $title;

		$w->process_template('page', $vars,
			"./docs/${lang}-${p}.html", $utf_conv);
	}
}


sub brands_page
# crea la página con los logotipos de las marcas
{
	my ($w, $lang) = @_;

	print "\t(Venexma) brands...\n" if $w->{'verbose'};

	open F, 'marcas' or die "Can't open 'marcas'";
	my @logos = <F>;
	chomp(@logos);
	close F;

	my $vars = $w->default_tt_vars($lang, 'brand');
	$vars->{logos} = \@logos;

	$w->process_template('brand', $vars, "./output/${lang}-brand.html");
}


1;
